@@ -232,3 +232,8 @@ def dict2list(data: dict, data_key="count", key_name="key", value_name="value"):
             value = value.get(data_key)
         result.append({key_name: key, value_name: value})
     return result
+
+
+class ReadOnlyDict(dict):
+    def __setitem__(self, key, value):
+        raise NotImplementedError("Dictionary is read-only")
